@@ -1,14 +1,18 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """
+trashpanda is a collection of helper methods composing tasks around pandas.DataFrames
+and Series.
+
 .. doctest::
+   :hide:
 
     # Test for wrong __all__ module attribute.
     >>> from trashpanda import *
 """
 __author__ = """David Scheliga"""
 __email__ = "david.scheliga@gmx.de"
-__version__ = "1.0.0"
+__version__ = "1.1.0"
 __all__ = [
     "add_blank_rows",
     "add_columns_to_dataframe",
@@ -17,6 +21,7 @@ __all__ = [
     "cut_before",
     "cut_dataframe_after_max",
     "cut_series_after_max",
+    "DEFAULT_NA",
     "get_intersection",
     "get_unique_index_positions",
     "find_index_of_value_in_series",
@@ -55,7 +60,11 @@ writes_logs_onto_console.setFormatter(
 )
 
 
-DEFAULT_NA = pandas.NA
+DEFAULT_NA = numpy.NaN
+"""
+The default NaN representation used for undefined values. Current representation is 
+*numpy.NaN*.
+"""
 
 
 @overload
@@ -652,7 +661,7 @@ def _add_blank_rows_to_dataframe(
 
     """
     if fill_value is None:
-        fill_value = numpy.nan
+        fill_value = DEFAULT_NA
 
     nothing_do_add_just_copy_source = len(indexes_to_add) == 0
     if nothing_do_add_just_copy_source:
@@ -740,9 +749,10 @@ def add_columns_to_dataframe(
         0  0  1  +  +
         1  2  3  +  +
         >>> add_columns_to_dataframe(sample_series, ["d", "c"])
-           b  a     d     c
-        0  0  1  <NA>  <NA>
-        1  2  3  <NA>  <NA>
+           b  a   d   c
+        0  0  1 NaN NaN
+        1  2  3 NaN NaN
+
     """
     if fill_value is None:
         fill_value = DEFAULT_NA
@@ -1045,18 +1055,18 @@ def override_left_with_right_dataframe(
         a  3  4
         d  3  4
         >>> override_left_with_right_dataframe(left, right)
-           m    x     z
-        a  4  2.0     3
-        b  1  2.0  <NA>
-        c  1  2.0  <NA>
-        d  4  NaN     3
+           m    x    z
+        a  4  2.0  3.0
+        b  1  2.0  NaN
+        c  1  2.0  NaN
+        d  4  NaN  3.0
 
     """
     old_frame = left_target.copy()
     columns_to_add = overriding_right.columns.difference(left_target.columns)
     if not columns_to_add.empty:
         for column_name in columns_to_add:
-            old_frame[column_name] = pandas.NA
+            old_frame[column_name] = DEFAULT_NA
     targeted_columns = overriding_right.columns
     same_indexes = overriding_right.index.intersection(old_frame.index)
     new_indexes = overriding_right.index.difference(old_frame.index)
@@ -1686,6 +1696,12 @@ def add_missing_indexes_to_series(
     """
     Adds different (missing) indexes to series.
 
+    Notes:
+        If no explicit fill value is defined, trashpanda.DEFAULT_NA will be used,
+        which is currently numpy.NaN. Be aware that integer arrays cannot contain
+        NaN values as these are special values for float arrays only. To preserve
+        integer arrays the fill value must be an integer.
+
     Args:
         target_series(Series):
             Series in which missing indexes should be added.
@@ -1701,6 +1717,7 @@ def add_missing_indexes_to_series(
 
     Examples:
         >>> from pandas import Series, Index, Int16Dtype
+        >>> from doctestprinter import print_pandas
         >>> import numpy as np
         >>> target = Series(
         ...     np.full(3, 1), index=list(iter("abc")), name="foo", dtype=Int16Dtype()
@@ -1710,20 +1727,31 @@ def add_missing_indexes_to_series(
         b    1
         c    1
         Name: foo, dtype: Int16
+
+        Because new indexes are represented as numpy.NaN the resulting datatype
+        cannot be integer. In dependendy of the current python version either a
+        object or float type is returned.
+
         >>> new_indexes_to_add = Index(list(iter("ad")))
-        >>> add_missing_indexes_to_series(target, new_indexes_to_add)
-        a       1
-        b       1
-        c       1
-        d    <NA>
-        Name: foo, dtype: object
-        >>> add_missing_indexes_to_series(target, new_indexes_to_add, "X")
+        >>> float_sample = add_missing_indexes_to_series(target, new_indexes_to_add)
+        >>> str(float_sample.dtype) == str(target.dtype)
+        False
+        >>> print_pandas(float_sample)
+           foo
+        a    1
+        b    1
+        c    1
+        d  nan
+
+        >>> obj_sample = add_missing_indexes_to_series(target, new_indexes_to_add, "X")
+        >>> obj_sample
         a    1
         b    1
         c    1
         d    X
         Name: foo, dtype: object
 
+
     """
     if fill_value is None:
         fill_value = DEFAULT_NA
@@ -1733,7 +1761,9 @@ def add_missing_indexes_to_series(
         missing_indexes = new_indexes.difference(old_series.index)
     except AttributeError:
         raise TypeError("new_indexes must be of pandas.Index type.")
-    new_rows = Series([fill_value] * len(missing_indexes), index=missing_indexes)
+    missing_index_count = len(missing_indexes)
+    missing_fill_values = numpy.full(missing_index_count, fill_value)
+    new_rows = Series(missing_fill_values, index=missing_indexes)
     overridden_series = pandas.concat([old_series, new_rows], sort=True)
     overridden_series.name = old_series.name
     return overridden_series
